@@ -38,11 +38,12 @@ class SFTPFile(NetFile):
             return
 
         o = urlparse(self._url)
-        creds = self._host_auth[o.hostname]
+        host_name = o.hostname.strip(':')
+        creds = self._host_auth[host_name]
 
         self._ssh_client = paramiko.SSHClient()
         self._ssh_client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
-        self._ssh_client.connect(o.hostname.strip(':'), username=creds[0], password=creds[1])
+        self._ssh_client.connect(host_name, username=creds[0], password=creds[1])
         self._sftp = self._ssh_client.open_sftp()
         self._sftp_file = self._sftp.open(o.path)
 
